/*
 * checkPoint.h - Emerald checkPoint operation, external interface
 *
 * Copyright 1987 Clinton Jeffery
 * Last edit: 11/19/87
 *
 * The checkpoint on disk consists of two components: a database
 * of checkpointed objects, and a log file.  The database is also
 * kept online in main memory as a write through 'cache'.  All
 * kernel access to the checkpoint is through two primitives; these
 * primitves in turn call database and log file routines as needed.
 */

extern void CPInit();
/*
 * CPInit is responsible for opening and loading the
 * database file, and then recovering all valid checkpointed
 * objects.  During the recovery process, a new log file is written;
 * the old one is discarded.  Thus garbage collection is performed
 * each time the kernel restarts.
 */

extern void Checkpoint();
/*
 * CheckPoint writes a new copy of the current global object to the
 * log file, and updates the database accordingly.
 * The initial checkpoint of an object results in new entries in
 * both the log file and the database.  Subsequent checkpoints
 * result in a new entry to the log file (no real-time garbage
 * collection), an an update to the database entry.
 */
