/* File: /u1/Eden/Source/MsgOps/edenPorts.h */

/*
 * $Header:   /u1/Eden/Source/MsgOps/RCS/edenPorts.v  Revision 2.2  84/02/16  20:33:28  oystr  Exp$
 * INTERFACE:	None.
 *
 * FUNCTION:	Define the types and constants associated with the Eden
 *		port system.  This attempts to isolate as much of Eden
 *		proper as possible from the underlying IPC mechanism.
 *
 * IMPORTS:	The concept of port defined by the underlying IPC mechanism.
 *		In the particular case the type EdenPort must coincide exactly
 *		with the CMU-IPC definition of `localport'.
 *              /u1/Eden/StdTypes.h,
 *              /u1/Eden/Source/MsgOps/MsgDefs.h.
 *
 * EXPORTS:	EdenPort, EdenPortName, MAXPORTNAME, NULLEDENPORT,
 *              MMCreatePort, MMRemovePort, MMConnectPort, MMNamePort,
 *              MMInitPorts, MMPortDeathInterrupt, MMMsgAccepted,
 *              MMCleanPortHandler, MMSendIPCMsg.
 *
 * DESIGN:	Ad Hoc - just a front end to the most widely used CMU-IPC
 *		procedures.
 *
 * $Log:	/u1/Eden/Source/MsgOps/RCS/edenPorts.v $
Revision 2.2  84/02/16  20:33:28  oystr
Checking version update is OK. No changes.

Revision 2.1  84/02/16  20:22:32  oystr
Version 2 baseline

Revision 1.7  84/02/16  15:13:51  eric
Proper port cleanup on port death implemented (ipc emergency signal
handling).

Minor fixes:
Signal handlers now 'proctect' QueueTask via 'HoldSigs(); ... ; ReleaseSigs()'
Minor bug in TimerCode fixed.

NOTE:  The message module now makes heavy use of the HOTS table when
using the Ether.  The HOTS table lookup routine has been optimized
new hashing function and a one-element cache.

Revision 1.5  83/02/25  11:21:32  cady
Fixed MsgDef.h include.

Revision 1.4  83/02/25  11:19:04  cady
Added include for MsgDefs.h.

Revision 1.3  83/02/25  11:15:44  cady
Added include for MsgDefs.h.

Revision 1.2  83/02/22  12:02:48  cady
Added MMNamePort primitive.

Revision 1.1  83/01/06  14:32:28  cady
Initial revision

 * 30-Dec-1982: Internode communication added. S. Cady.
 * 27-Nov-1982: Revised for incorporation into Message Module. S. Cady
 * 16-Nov-1982:	Initial implementation. J. Sanislo.
 */

/****************************************************************/
/*              Global Eden Port Type Definitions               */
/****************************************************************/

#ifndef edenPorts
#define edenPorts

/* Must correspond to the IPC NULLPORT */

#define NULLEDENPORT 0
#define NETPORT      NULLEDENPORT

#define EdenPort unsigned char

#define MAXPORTNAME 32
#define NULLNAME     0

typedef char EdenPortName[MAXPORTNAME];

#ifndef stdTypes
#include "Kernel/h/stdTypes.h"
#endif

#include "Kernel/h/mmMsgDefs.h"

/*   Message Module Eden Port Library External Definitions       */

extern KKStatus MMCreatePort(),
                MMRemovePort(),
                MMConnectPort(),
                MMNamePort();

extern void     MMInitPorts(),
                MMPortDeathInterrupt(),
                MMMsgAccepted(),
                MMCleanPortHandler();
extern KKStatus MMSendIPCMsg();

#endif

/****************************************************************/
/*          End of Global Eden Port Type Definitions            */
/****************************************************************/
