/*
 * $Header:   /u1/Eden/Kernel/h/hotsTypes.v  Revision 3.2  84/12/17  16:30:23  schwartz  Exp$
 * INTERFACE : None
 * FUNCTION  : Definition of the types used in the HOTS structure.
 *             This file contains the type definitions used in the implementation
 *             of the HOTS data structure.  The types defined are: NodeStatus,
 *             NodeCharacteristics, and HOTSRecord.
 * IMPORTS   : Type definitions as shown below: OBSOLETE!!!
 *              TimeStamp           from /u1/Eden/Source/CapaOps/CapaTypes.h
 *              Boolean and NodeNum from /u1/Eden/StdTypes.h
 *              EdenPort            from /u1/Eden/Source/MsgOps/edenPorts.h
 *              EtherNetAddress     from /u1/Eden/Source/MsgOps/EtherTypes.h
 * EXPORTS   : The following type definitions:
 *             NodeStatus, NodeCharacteristics, BitMap32, and HOTSRecord.
 * DESIGN    : 
 * $Log:	/u1/Eden/Source/DStructs/HOTS/RCS/HOTSTypes.v $
Revision 3.2  84/12/17  16:30:23  schwartz
Added field (FirstFCMsgSent) to HOTS record structure, so that it is possible
for the Message Module to recognize first flow-controlled messages from newly
booting nodes.

Revision 3.1  84/11/19  15:01:15  schwartz
Fixed KMD routines so they can print the names of any physical host, and
so they know about NodeCharacteristics IsBrdcstProcess and IsEFTServer,
and so that they correctly determine the default Nodes. 

Revision 3.0  84/07/04  00:04:02  schwartz
Changes for port of Eden to Sun workstations

Revision 2.1  84/02/16  22:01:30  oystr
Version 2 baseline.

Revision 1.4  84/02/16  13:45:50  eric
Major revision of the Message Module requiring introduction of new
fields on a per node basis in the HOTS table.

Revision 1.3  83/02/25  11:45:45  venkat
Included the definitions of exported functions.

Revision 1.2  83/02/24  13:45:53  oystr
Changed type of NodeStat field from BitMap32 to NodeStatus.

Revision 1.1  83/01/04  15:15:00  venkat
Initial revision

 *
 */

#ifndef hotsTypes
#define hotsTypes
#include "Kernel/h/stdTypes.h"
#include "Kernel/h/mmMsgDefs.h"
#include "Kernel/h/edenPorts.h"
#include "Kernel/h/mmEthrTypes.h"
#include "Kernel/h/mmKeyTypes.h"
#include "Kernel/h/mmMsgTypes.h"
/* Node characteristics as bit masks */
#define  IsVax            1
#define  IsSun            2
#define  IsRepository     4
#define  IsActiveNode     8
#define  HasPrinter      16
#define  HasDisplay      32
#define  IsBrdcstProcess 64
#define  IsEFTServer    128

typedef enum
    {Dead, Alive, Deaf, Dumb, Booting}
NodeStatus;

typedef int BitMap32;

typedef struct FrameStr {
    int                         RetransCount;
    struct FrameStr             *Next;
    EnetPacket                  packet;
 } Frame, *FramePtr;
 
#define NULLFP      (FramePtr) 0


typedef struct HOTSRec {
    NodeNum		LNN;
    EtherNetAddress	EtherAddr;
    NodeStatus		NodeStat;
    time_t  		LastMsgTs;
    Boolean		NodeIsLocal;
    EdenPort		NodeNetPort;
    time_t              NodeIncarnationId;
    struct LMMsg       *incomingLMQueue;
    /* The following fields are for the protocol manager. */
    FramePtr            ToSendPtr;
    FramePtr            SentPtr;
    KeyedQueue          RecvPtr;
    MsgSeqType          AckExpected;
    MsgSeqType          NextMsgToSend;
    MsgSeqType          NextSeqNo;
    MsgSeqType          TooFar;
    MsgSeqType          MsgExpected;
    MsgSeqType          LatestAck;
    int                 SendWindowSize;
    int                 OutOfOrderCount;
    Boolean             Timed;
    int                 AckTimerCount;
    int                 MsgTimerCount;
    struct HOTSRec     *TNext;
    struct HOTSRec     *TPrev;
    Boolean             NakSent,
			FirstFCMsgSent;
    int                 RetransCount,
                        NAKsSent,
                        NAKsRecv,
                        MsgDropped,
                        ACKsSent,
                        ACKsRecv,
                        MsgDelivered,
                        MsgAccepted;
} HOTSRecord, *HOTSRecordPtr;
typedef struct HOTStr
{
    HOTSRecord     ThisEntry;
    struct HOTStr *next;
};


extern KKStatus CreateHOTSRecord(), HOTSCreate(), HOTSInsert(),
                HOTSSearch(), HOTSSearchPtr(), HOTSReplace(), HOTSDelete(),
                PrintHOTSTable(), PrintHOTS();
extern HOTSRecord *HOTSTraverse();
extern void InitHOTS();

/*                                      */
/*  For Sequential Search of HOTS Table */
/*                                      */

#define InitNextHOTS( fIndex, fEntry )  \
    {   fIndex = -1;                    \
        fEntry = NULL;                  \
    }

#define  HOTSIZE   256          /* The size of the hash table; must be
                                   of the form 2**n                    */

extern struct HOTStr *HOTSTable[];
extern int  NoHOTSEntries;

extern KKStatus HOTSSearchPtr();

#endif hotsTypes


