/* File: /u1/Eden/Source/MsgOps/FifoTypes.h */

/*
 * $Header:   /u1/Eden/Source/MsgOps/RCS/FifoTypes.v  Revision 1.2  83/02/26  19:45:02  cady  Exp$
 * INTERFACE:	None.
 *
 * FUNCTION:	Provide the Message Module FIFO Queue Definitions.
 *
 * IMPORTS:	Eden/StdTypes.h,
 *              /u1/Eden/Source/MsgOps/MsgDefs.h.
 *
 * EXPORTS:	FifoElt, FifoEltPtr, FifoQueue, MMInitQ, MMEnterInQ, 
 *              MMGetFromQ, MMPurgeQ, mFifoEmpty.
 *
 * DESIGN:      FIFO queues are structured as singly linked lists
 *              of entries with a pointer to the head and tail.
 *              Each entry consists of a pointer to the following
 *              entry, a search key, and two words of data.
 *              The last entry points back to the head of the queue.
 *              The search key allows entries to be removed from
 *              the list out of order.
 *
 * $Log:	/u1/Eden/Source/MsgOps/RCS/FifoTypes.v $
Revision 1.2  83/02/26  19:45:02  cady
Modified include files to be explicit.

Revision 1.1  83/01/06  14:09:00  cady
Initial revision

 * 4-Nov-1982	Initial implementation. S. Cady
 */

#ifndef mmFifoTypes
#define mmFifoTypes

#ifndef stdTypes
#include "Kernel/h/stdTypes.h"
#endif

#ifndef mmMsgDefs
#include "Kernel/h/mmMsgDefs.h"
#endif

/****************************************************************/
/*              Global FIFO Queue Type Definitions              */
/****************************************************************/

typedef struct fifoelt          /* fifoelt is a C hack designed */
{                               /* to get around the compiler.  */
  struct fifoelt   *FifoNext;   /* It is never used again!      */
  UnsignedInteger   FifoKey;
  integer           FifoData[2];
}   FifoElt;

typedef FifoElt *FifoEltPtr;

typedef struct
{
  FifoEltPtr FifoHead;
  FifoEltPtr FifoTail;
}   FifoQueue;

#define mFifoEmpty(fQueue) ( (fQueue).FifoHead == NULL )

/*   Message Module FIFO Library External Definitions           */

extern KKStatus MMEnterInQ(),
                MMGetFromQ(),
                MMPurgeQ();

extern void     MMInitQ();

#endif

/****************************************************************/
/*          End of Global Fifo Queue Type Definitions           */
/****************************************************************/
