/* File: /u1/Eden/Source/MsgOps/KeyedTypes.h */

/*
 * $Header:   /u1/Eden/Source/MsgOps/RCS/KeyedTypes.v  Revision 1.2  83/02/26  19:45:18  cady  Exp$
 * INTERFACE:	None.
 *
 * FUNCTION:	Provide Message Module Keyed Queue Definitions.
 *
 * IMPORTS:	Eden/StdTypes, /u1/Eden/Source/MsgOps/MsgDefs.h.
 *
 * EXPORTS:	KEYEDSIZE, KeyedElt, KeyedEltPtr, KeyedQueue, MMInitList,
 *              MMEnterInList, MMGetFromLit, MMFindInList.
 *
 * DESIGN:      Keyed queues/lists are structured as hashed lists
 *              based on the search key.  Collisions on hashes
 *              are resolved by constructing a singly linked list
 *              of entries in decreasing order (of keys).  Each
 *              entry consists of a pointer to the next entry
 *              in the collision list, a search key, and two
 *              words of data.
 *
 * $Log:	/u1/Eden/Source/MsgOps/RCS/KeyedTypes.v $
Revision 1.2  83/02/26  19:45:18  cady
Modified include files to be explicit.

Revision 1.1  83/01/06  14:09:35  cady
Initial revision

 * 4-Nov-1982	Initial implementation. S. Cady
 */

#ifndef mmKeyTypes
#define mmKeyTypes

#ifndef stdTypes
#include "Kernel/h/stdTypes.h"
#endif

#ifndef mmMsgDefs
#include "Kernel/h/mmMsgDefs.h"
#endif

/****************************************************************/
/*              Global Keyed Queue Type Definitions             */
/****************************************************************/

#define KEYEDSIZE 13

typedef struct keyedelt         /* keyedelt is a C hack to fool */
{                               /* the compiler.  It is never   */
  struct keyedelt *KeyedNext;   /* used again.                  */
  UnsignedInteger  KeyedKey;
  integer          KeyedData[2];
}   KeyedElt;

typedef KeyedElt *KeyedEltPtr;

typedef KeyedEltPtr KeyedQueue[KEYEDSIZE];

/*   Message Module Keyed Library External Definitions          */

extern KKStatus MMEnterInList(),
                MMGetFromList(),
                MMFindInList();

extern void     MMInitList();

#endif

/****************************************************************/
/*          End of Global Keyed Queue Type Definitions          */
/****************************************************************/
