/* File: /u1/Eden/Source/MsgOps/MsgTypes.h */

/*
 * $Header:   /u1/Eden/Source/MsgOps/RCS/MsgTypes.v  Revision 2.1  84/02/16  20:35:55  oystr  Exp$
 * INTERFACE:	None.
 *
 * FUNCTION:	Provides the Message Module Message Library type
 *              and interface definitions.
 *
 * IMPORTS:     /u1/Eden/StdTypes.h,
 *              /u1/Eden/Source/MsgOps/MsgDefs.h.
 *
 * EXPORTS:	MessageHeader, Message, MessagePtr, MMAllocateMsg,
 *              MMDeallocateMsg, MMBuildMsg, MMSendMsg,
 *              MMSendSynchMsg, MMBroadcastMsg, MMReceiveMsg,
 *              MMCancelMsg, MessageHeaderPtr, MAXMESSAGESIZE,
 *              vMMForceAck, vMMTickSize, vMMMsgTimeout, vMMACKTimeout.
 *
 * DESIGN:      
 *
 * $Log:	/u1/Eden/Source/MsgOps/RCS/MsgTypes.v $

Revision 3.1 87/05/08   eric
Change declaration of MMEthernetInterrupt from void to int.

Revision 3.0 86/05/27   eric
Changed MsgHdr: removed Termination Handler stuff.
Inserted new field to contain source socket and ethernet address and
an incarnation id for the source.

Revision 2.2 84/08/3    richk
Changed MsgInReplyToId to InvHandle MsgLocalHandle in support of kernel
change of 6 ipc messages to 4 per invocation  This field is 
set by invoker eject and used for messages between invoker and host.

Revision 2.1  84/02/16  20:35:55  oystr
Version 2 baseline.

Revision 1.10  84/02/16  15:11:49  eric
Proper port cleanup on port death implemented (ipc emergency signal
handling).

Minor fixes:
Signal handlers now 'proctect' QueueTask via 'HoldSigs(); ... ; ReleaseSigs()'
Minor bug in TimerCode fixed.

NOTE:  The message module now makes heavy use of the HOTS table when
using the Ether.  The HOTS table lookup routine has been optimized
new hashing function and a one-element cache.

Revision 1.9  83/10/25  11:52:37  mager
Added BroadcastMask to MessageHeader; defined BroadcastMask offset.

Revision 1.8  83/10/16  15:22:05  mager
Added include of file EtherTypes.h

Revision 1.7  83/10/14  16:39:48  mager
Removed Datagram level of Message Module.  Increased size of message to just
under 1K. Changed calls to malloc and free with xalloc and xfree.
Removed redundant setting of ipc header.
Reduced initialization of messages in MMAllocateMsg.

Revision 1.5  83/05/27  11:25:58  cady
Changed MsgSrcNode to MsgSrc and MsgDestNode to MsgDest.

Revision 1.4  83/05/27  09:11:47  oystr
Added conditional include of edenPorts.h, since this is now used
by MsgTypes.

Revision 1.3  83/05/27  00:16:22  cady
Revised datagram and message headers.
Eliminated DGListElt structure.
Decreased datagram size to 512 bytes.
Revised asynchronous send to send immediately.
Revised SendDG to used separate header and data pointers.
Revised IPC header structure for send and receive.

Revision 1.2  83/02/26  19:45:38  cady
Modified include files to be explicit.

Revision 1.1  83/01/06  14:11:52  cady
Initial revision

 * 4-Nov-1982	Initial implementation. S. Cady
 */

#include "Kernel/h/mmMsgDefs.h"

#ifndef mmMsgTypes
#define mmMsgTypes

#ifndef stdTypes
#include "Kernel/h/stdTypes.h"
#endif

#ifndef edenPorts
#include "Kernel/h/edenPorts.h"
#endif

#ifndef mmEthrTypes
#include "Kernel/h/mmEthrTypes.h"
#endif

/****************************************************************/
/*              Global Message Type Definitions                 */
/****************************************************************/


/***************************WARNING******************************/
/*  If packing is done on these structs, watch out for          */
/*  inconsistency between usage in the Message Module and in    */
/*  any message definitions.  Specifically, the space between   */
/*  the msg header and the data must always agree.              */
/****************************************************************/

typedef struct
{
    short int        MsgVersion;
    MsgSeqType       MsgSeq;
    MsgSeqType       MsgAck;

    /* The following fields used to be termination handlers now they hold
       the address of the Ethernet socket whereto reply messages can be sent
    */
    struct in_addr   SrcSinAddr;
    u_short          SrcSinPort;
    u_short	     MsgPadForSun1;
    long             MsgReserved; /* for size compatability */
    /* End old fields */

    /* BroadcastMask really belongs in the EnetHeader. */
    short int        BroadcastMask; 
    u_short	     MsgPadForSun2;

    MessageId        MsgId;
    EdenPort         MsgSrcPort;
    SubNetType       SNType;
    NodeNum          MsgSrc;
    EdenPort         MsgDestPort;
    char             MsgPad2;
    NodeNum          MsgDest;

    MessageType      MsgType;
    MessageSubtype   MsgSubtype;
    UnsignedInteger  MsgSize;
    time_t           SrcIncarnationId;
} MessageHeader, *MessageHeaderPtr;

#define MessageHdrSize (sizeof(MessageHeader))
#define MAXMESSAGESIZE  (MAXPACKETSIZE - MessageHdrSize)


#define Message(fMsgSize)                               \
  struct {                                              \
           MessageHeader MsgHdr;                        \
           int           MsgData[mBytesToInt(fMsgSize)]; \
         }

typedef Message(MAXMESSAGESIZE) *MessagePtr;

/* Byte offset of DestNode and BroadcastMask fields within Msg header   */
#define DestNodeOffset ((int) (&((MessageHeaderPtr) NULL) -> MsgDest))
#define BroadcastMaskOffset ((int) (&((MessageHeaderPtr)NULL)->BroadcastMask))

typedef struct { 
    Boolean         DeviceLocal:1;
    unsigned int    DeviceUnused:7;
    EdenPort        DevicePort;
    EtherNetAddress DeviceEnet;
} DeviceAddr;

typedef struct
{
  Message(MAXMESSAGESIZE)   EnetData;
} EnetPacket, *EnetPacketPtr;


/*   Message Module Message Library External Definitions         */

extern KKStatus MMAllocateMsg(),
                MMDefineUpcallHandler(),
                MMSendMsg(),
                MMSendSynchMsg(),
                MMSendRawMsg(),
                MMSendSynchRawMsg(),
                MMBroadcastMsg(),
                MMReceiveMsg(),
                MMCancelMsg();

extern void     MMDeallocateMsg(),
                MMBuildMsg(),
                MMEmergencyInterrupt(),
                MMNormalInterrupt(),
                MMReceiveHandler();
extern void     MMInitHOTSEntry(),
                MMRemoteNodeDeath();
extern KKStatus MMInitHOTSLNN();
extern int      vMMForceAck, vMMTickSize, vMMMsgTimeout, vMMACKTimeout,
                MMEthernetInterrupt();

extern KKStatus MMDispatchMsg();
                
#ifndef MMDefineMsgHandler
extern KKStatus MMDefineMsgHandler();
#endif MMDefineMsgHandler


#define MMRemoveMsgHandler( fType, fSubtype, fOldHandler ) \
   MMDefineMsgHandler (fType, fSubtype, NULL, fOldHandler )

#endif

/****************************************************************/
/*          End of Message Library Type Definitions             */
/****************************************************************/
