/* File: ~eden/Kernel/h/mmTypes.h */

/*
 * $Header:   ~eden/Kernel/h/Types.v  Revision 3.0  84/07/03  08:43:03  schwartz  Exp$
 * INTERFACE:	None.
 *
 * FUNCTION:	Defines data type and external definitions local
 *              to Message Module routines.
 *
 * IMPORTS:	stdTypes.h,
 *              MsgDefs.h, FifoTypes.h, edenPorts.h, EtherTypes.h.
 *
 * EXPORTS:     FIRSTMSGID, MAXMSGID, GetLNN, MMLocalLNN,
 *              MMNetPort, MMNextMsgId, mBuildNetName, MMEtherFile.
 *
 * DESIGN:      None, of course.
 *
 * $Log:	/u1/Eden/Source/MsgOps/RCS/Types.v $
Revision 3.0  84/07/03  08:43:03  schwartz
Changes to accommodate Unix 4.2 sockets for network interprocess communication

Revision 2.1  84/02/16  20:28:53  oystr
Verserion 2 baseline.

Revision 1.12  84/02/16  15:13:03  eric
Proper port cleanup on port death implemented (ipc emergency signal
handling).

Minor fixes:
Signal handlers now 'proctect' QueueTask via 'HoldSigs(); ... ; ReleaseSigs()'
Minor bug in TimerCode fixed.

NOTE:  The message module now makes heavy use of the HOTS table when
using the Ether.  The HOTS table lookup routine has been optimized
new hashing function and a one-element cache.

Revision 1.11  83/05/27  10:28:15  cady
Removed sys/types.h include and changed EnetPacket.

Revision 1.10  83/05/27  00:59:48  cady
Added #ifndef u_char check.

Revision 1.9  83/05/27  00:48:56  cady
Added include for sys/types.h

Revision 1.8  83/05/27  00:17:22  cady
Revised datagram and message headers.
Eliminated DGListElt structure.
Decreased datagram size to 512 bytes.
Revised asynchronous send to send immediately.
Revised SendDG to used separate header and data pointers.
Revised IPC header structure for send and receive.

Revision 1.7  83/05/16  16:45:09  cady
Added explicit constant typing and include files.

Revision 1.6  83/02/26  19:46:13  cady
Modified include files to be explicit.

Revision 1.5  83/02/25  11:08:33  cady
Moved external trace definitions from Types.h to MsgDefs.h.

Revision 1.4  83/02/24  16:33:30  cady
Added external Trace definitions.

Revision 1.3  83/02/22  12:01:40  cady
Deleted Debug definition.

Revision 1.2  83/01/11  15:23:03  cady
Changed NETPORT IPC port to NETPORT%04x.

Revision 1.1  83/01/06  14:08:10  cady
Initial revision

 * 30-Dec-1982  Internode communication added. S. Cady.
 * 4-Nov-1982	Initial implementation. S. Cady
 */

#include <stdio.h>
#include "Kernel/h/stdTypes.h"
#include "Kernel/h/mmMsgDefs.h"
#include "Kernel/h/mmFifoTypes.h"
#include "Kernel/h/mmEthrTypes.h"
#include "Kernel/h/edenPorts.h"

/****************************************************************/
/*              General Message Module Type Definitions         */
/****************************************************************/

#define BITSPERBYTE 8

#define FIRSTMSGID ((MessageId)         1)
#define MAXMSGID   ((MessageId) 0x0007fff)

extern NodeNum   GetLNN();
extern NodeNum   MMLocalLNN;
extern EdenPort  MMNetPort;
extern MessageId MMNextMsgId;

extern int             MMEtherFile;
extern EtherNetAddress MMLocalEtherNet;

#define mBuildNetName( fName, fLNN ) sprintf( fName, "NETPORT%04x", fLNN )

#if defined(sun) && defined(WASHINGTON)
#define COPYADDR(A, B, C) bcopy((char *)&(A), (char *)B, C)
#else
#define COPYADDR(A, B, C) bcopy((char *) (A), (char *)B, C)
#endif

/****************************************************************/
/*          End of General Message Module Type Definitions      */
/****************************************************************/
