/* File: ~eden/Kernel/UnixHacks/unixCodes.m */

/*
 * $Header:$
 * INTERFACE:	None.
 *
 * FUNCTION:	Define the standard error codes associated with
 *              Unix system calls.  Note that these codes are
 *              directly related to the error codes defined in
 *              /usr/include/errno.h.
 *
 * IMPORTS:	/u1/Eden/ErrCodes/errMsgs.
 *
 * EXPORTS:	A set of #defined constants representing the error
 *		codes returned by Unix system calls.
 *
 * DESIGN:	
 *
 * $Log:	/u1/Eden/ErrCodes/RCS/SYScodes.v $
Revision 1.2  84/06/30  00:05:12  schwartz
Added new error codes from Unix 4.2 file /usr/include/errno.h

Revision 1.1  83/01/07  12:01:12  cady
Initial revision

 * 1-Dec-1982:	Initial implementation. S. Cady.
 */
#ifndef unixCodes
#define unixCodes

#ifndef errMsgs
#include "Kernel/h/errMsgs.h"
#endif

#define	FAC_System		((unsigned)0x0000000F)
#define	VER_System		((unsigned)0x00000001)
#define	ABV_System		"SYS"

/* The following macro converts an error status found in */
/* the global variable errno to a SYS error code.        */

#define mSystemError(ferrno)    \
            ( (FAC_System << 16) + ((ferrno) * 8) + SEVERE )

/*
 * Severe error codes, since they indicate we are bumping up against
 * the underlying Unix system.
 */
#define	SYSK_EPERM		((unsigned)0x000F000C)
/* "Not owner." */
#define	SYSK_ENOENT		((unsigned)0x000F0014)
/* "No such file or directory." */
#define	SYSK_ESRCH		((unsigned)0x000F001C)
/* "No such process." */
#define	SYSK_EINTR		((unsigned)0x000F0024)
/* "Interrupted system call." */
#define	SYSK_EIO		((unsigned)0x000F002C)
/* "I/O error." */
#define	SYSK_ENXIO		((unsigned)0x000F0034)
/* "No such device or address." */
#define	SYSK_E2BIG		((unsigned)0x000F003C)
/* "Arg. list too long." */
#define	SYSK_ENOEXEC		((unsigned)0x000F0044)
/* "Exec format error." */
#define	SYSK_EBADF		((unsigned)0x000F004C)
/* "Bad file number." */
#define	SYSK_ECHILD		((unsigned)0x000F0054)
/* "No children." */
#define	SYSK_EAGAIN		((unsigned)0x000F005C)
/* "No more processes." */
#define	SYSK_ENOMEM		((unsigned)0x000F0064)
/* "Not enough core." */
#define	SYSK_EACCES		((unsigned)0x000F006C)
/* "Permission denied." */
#define	SYSK_EFAULT		((unsigned)0x000F0074)
/* "Bad address." */
#define	SYSK_ENOTBLK		((unsigned)0x000F007C)
/* "Block device required." */
#define	SYSK_EBUSY		((unsigned)0x000F0084)
/* "Mount device busy." */
#define	SYSK_EEXIST		((unsigned)0x000F008C)
/* "File exists." */
#define	SYSK_EXDEV		((unsigned)0x000F0094)
/* "Cross-device link." */
#define	SYSK_ENODEV		((unsigned)0x000F009C)
/* "No such device." */
#define	SYSK_ENOTDIR		((unsigned)0x000F00A4)
/* "Not a directory." */
#define	SYSK_EISDIR		((unsigned)0x000F00AC)
/* "Is a directory." */
#define	SYSK_EINVAL		((unsigned)0x000F00B4)
/* "Invalid argument." */
#define	SYSK_ENFILE		((unsigned)0x000F00BC)
/* "File table overflow." */
#define	SYSK_EMFILE		((unsigned)0x000F00C4)
/* "Too many open files." */
#define	SYSK_ENOTTY		((unsigned)0x000F00CC)
/* "Not a typewriter." */
#define	SYSK_ETXTBSY		((unsigned)0x000F00D4)
/* "Text file busy." */
#define	SYSK_EFBIG		((unsigned)0x000F00DC)
/* "File too large." */
#define	SYSK_ENOSPC		((unsigned)0x000F00E4)
/* "No space left on device." */
#define	SYSK_ESPIPE		((unsigned)0x000F00EC)
/* "Illegal seek." */
#define	SYSK_EROFS		((unsigned)0x000F00F4)
/* "Read-only file system." */
#define	SYSK_EMLINK		((unsigned)0x000F00FC)
/* "Too many links." */
#define	SYSK_EPIPE		((unsigned)0x000F0104)
/* "Broken pipe." */

/* math software */
#define	SYSK_EDOM		((unsigned)0x000F010C)
/* "Math argument." */
#define	SYSK_ERANGE		((unsigned)0x000F0114)
/* "Result too large." */

/* non-blocking and interrupt i/o */
#define	SYSK_EWOULDBLOCK		((unsigned)0x000F011C)
/* "Operation would block" */
#define	SYSK_EINPROGRESS		((unsigned)0x000F0124)
/* "Operation now in progress" */
#define	SYSK_EALREADY		((unsigned)0x000F012C)
/* "Operation already in progress" */

/* ipc/network software */

		/* argument errors */
#define	SYSK_ENOTSOCK		((unsigned)0x000F0134)
/* "Socket operation on non-socket" */
#define	SYSK_EDESTADDRREQ		((unsigned)0x000F013C)
/* "Destination address required" */
#define	SYSK_EMSGSIZE		((unsigned)0x000F0144)
/* "Message too long" */
#define	SYSK_EPROTOTYPE		((unsigned)0x000F014C)
/* "Protocol wrong type for socket" */
#define	SYSK_ENOPROTOOPT		((unsigned)0x000F0154)
/* "Protocol not available" */
#define	SYSK_EPROTONOSUPPORT		((unsigned)0x000F015C)
/* "Protocol not supported" */
#define	SYSK_ESOCKTNOSUPPORT		((unsigned)0x000F0164)
/* "Socket type not supported" */
#define	SYSK_EOPNOTSUPP		((unsigned)0x000F016C)
/* "Operation not supported on socket" */
#define	SYSK_EPFNOSUPPORT		((unsigned)0x000F0174)
/* "Protocol family not supported" */
#define	SYSK_EAFNOSUPPORT		((unsigned)0x000F017C)
/* "Address family not supported by protocol family" */
#define	SYSK_EADDRINUSE		((unsigned)0x000F0184)
/* "Address already in use" */
#define	SYSK_EADDRNOTAVAIL		((unsigned)0x000F018C)
/* "Can't assign requested address" */

		/* operational errors */
#define	SYSK_ENETDOWN		((unsigned)0x000F0194)
/* "Network is down" */
#define	SYSK_ENETUNREACH		((unsigned)0x000F019C)
/* "Network is unreachable" */
#define	SYSK_ENETRESET		((unsigned)0x000F01A4)
/* "Network dropped connection on reset" */
#define	SYSK_ECONNABORTED		((unsigned)0x000F01AC)
/* "Software caused connection abort" */
#define	SYSK_ECONNRESET		((unsigned)0x000F01B4)
/* "Connection reset by peer" */
#define	SYSK_ENOBUFS		((unsigned)0x000F01BC)
/* "No buffer space available" */
#define	SYSK_EISCONN		((unsigned)0x000F01C4)
/* "Socket is already connected" */
#define	SYSK_ENOTCONN		((unsigned)0x000F01CC)
/* "Socket is not connected" */
#define	SYSK_ESHUTDOWN		((unsigned)0x000F01D4)
/* "Can't send after socket shutdown" */
#define	SYSK_ETOOMANYREFS		((unsigned)0x000F01DC)
/* "Too many references: can't splice" */
#define	SYSK_ETIMEDOUT		((unsigned)0x000F01E4)
/* "Connection timed out" */
#define	SYSK_ECONNREFUSED		((unsigned)0x000F01EC)
/* "Connection refused" */

		/* */
#define	SYSK_ELOOP		((unsigned)0x000F01F4)
/* "Too many levels of symbolic links" */
#define	SYSK_ENAMETOOLONG		((unsigned)0x000F01FC)
/* "File name too long" */

/* should be rearranged */
#define	SYSK_EHOSTDOWN		((unsigned)0x000F0204)
/* "Host is down" */
#define	SYSK_EHOSTUNREACH		((unsigned)0x000F020C)
/* "No route to host" */
#define	SYSK_ENOTEMPTY		((unsigned)0x000F0214)
/* "Directory not empty" */

/* quotas & mush */
#define	SYSK_EPROCLIM		((unsigned)0x000F021C)
/* "Too many processes" */
#define	SYSK_EUSERS		((unsigned)0x000F0224)
/* "Too many users" */
#define	SYSK_EDQUOT		((unsigned)0x000F022C)
/* "Disc quota exceeded" */

#endif

